summaryrefslogtreecommitdiffstats
path: root/examples
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:14:34 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-26 13:14:34 -0600
commit57e2ced52bf3ba886bb7710212167a86e20305e6 (patch)
treee08b1e82e83f5afa861dc9eeb833dc4bd593900b /examples
parentccad7a42d96879251c4971e51aac269f61a0ccf8 (diff)
downloadpytde-57e2ced52bf3ba886bb7710212167a86e20305e6.tar.gz
pytde-57e2ced52bf3ba886bb7710212167a86e20305e6.zip
Rename a number of libraries and executables to avoid conflicts with KDE4
Diffstat (limited to 'examples')
-rw-r--r--examples/pyKHTMLPart.py4
-rw-r--r--examples/pytde-sampler/gen_todo.py2
-rw-r--r--examples/pytde-sampler/qt_widgets/CONTRIB110
-rwxr-xr-xexamples/pytde-sampler/sampler.py6
-rw-r--r--examples/uitdemdi.py (renamed from examples/uikmdi.py)8
-rw-r--r--examples/uitdemdi.rc (renamed from examples/uikmdi.rc)0
6 files changed, 65 insertions, 65 deletions
diff --git a/examples/pyKHTMLPart.py b/examples/pyKHTMLPart.py
index e483d6f..2795526 100644
--- a/examples/pyKHTMLPart.py
+++ b/examples/pyKHTMLPart.py
@@ -51,10 +51,10 @@ from qt import TQString, TQStringList
from kio import KTrader
-from khtml import KHTMLPart, KHTMLView
+from tdehtml import KHTMLPart, KHTMLView
# Importing the KParts namespace gets us all of the KParts:: classes
-from kparts import KParts, createReadOnlyPart, createReadWritePart
+from tdeparts import KParts, createReadOnlyPart, createReadWritePart
import sys, os
diff --git a/examples/pytde-sampler/gen_todo.py b/examples/pytde-sampler/gen_todo.py
index 6abd5be..d094ab6 100644
--- a/examples/pytde-sampler/gen_todo.py
+++ b/examples/pytde-sampler/gen_todo.py
@@ -1,4 +1,4 @@
-mods = ['dcop', 'tdecore', 'tdefx', 'tdeprint', 'tdesu', 'tdeui', 'kfile', 'khtml', 'kio', 'kmdi', 'kparts', 'kspell', ]
+mods = ['dcop', 'tdecore', 'tdefx', 'tdeprint', 'tdesu', 'tdeui', 'kfile', 'tdehtml', 'kio', 'tdemdi', 'tdeparts', 'tdespell', ]
all = []
diff --git a/examples/pytde-sampler/qt_widgets/CONTRIB b/examples/pytde-sampler/qt_widgets/CONTRIB
index bf546f4..ea10773 100644
--- a/examples/pytde-sampler/qt_widgets/CONTRIB
+++ b/examples/pytde-sampler/qt_widgets/CONTRIB
@@ -392,10 +392,10 @@ kfile,KURLComboRequester,,,
kfile,KURLPropsPlugin,,,
kfile,KURLRequester,,,
kfile,KURLRequesterDlg,,,
-khtml,DOM,,,
-khtml,KHTMLPart,,,
-khtml,KHTMLSettings,,,
-khtml,KHTMLView,,,
+tdehtml,DOM,,,
+tdehtml,KHTMLPart,,,
+tdehtml,KHTMLSettings,,,
+tdehtml,KHTMLView,,,
kio,KAr,,,
kio,KArchive,,,
kio,KArchiveDirectory,,,
@@ -484,54 +484,54 @@ kio,ThumbCreator,,,
kio,testKIOMetaData,,,
kio,testKIOUDSEntry,,,
kio,testKIOUDSEntryList,,,
-kmdi,KMdi,,,
-kmdi,KMdiChildArea,,,
-kmdi,KMdiChildFrm,,,
-kmdi,KMdiChildFrmCaption,,,
-kmdi,KMdiChildFrmDragBeginEvent,,,
-kmdi,KMdiChildFrmDragEndEvent,,,
-kmdi,KMdiChildFrmMoveEvent,,,
-kmdi,KMdiChildFrmResizeBeginEvent,,,
-kmdi,KMdiChildFrmResizeEndEvent,,,
-kmdi,KMdiChildView,,,
-kmdi,KMdiMainFrm,,,
-kmdi,KMdiTaskBar,,,
-kmdi,KMdiTaskBarButton,,,
-kmdi,KMdiToolViewAccessor,,,
-kmdi,KMdiViewCloseEvent,,,
-kmdi,KMdiWin32IconButton,,,
-kparts,KParts,,,
-kparts,createReadOnlyPart,,,
-kparts,createReadWritePart,,,
-kparts,testTQMapTQCStringInt,,,
-kspell,KS_ADD,,,
-kspell,KS_CANCEL,,,
-kspell,KS_CLIENT_ASPELL,,,
-kspell,KS_CLIENT_HSPELL,,,
-kspell,KS_CLIENT_ISPELL,,,
-kspell,KS_CONFIG,,,
-kspell,KS_E_ASCII,,,
-kspell,KS_E_CP1251,,,
-kspell,KS_E_CP1255,,,
-kspell,KS_E_KOI8R,,,
-kspell,KS_E_KOI8U,,,
-kspell,KS_E_LATIN1,,,
-kspell,KS_E_LATIN13,,,
-kspell,KS_E_LATIN15,,,
-kspell,KS_E_LATIN2,,,
-kspell,KS_E_LATIN3,,,
-kspell,KS_E_LATIN4,,,
-kspell,KS_E_LATIN5,,,
-kspell,KS_E_LATIN7,,,
-kspell,KS_E_LATIN8,,,
-kspell,KS_E_LATIN9,,,
-kspell,KS_E_UTF8,,,
-kspell,KS_IGNORE,,,
-kspell,KS_IGNOREALL,,,
-kspell,KS_REPLACE,,,
-kspell,KS_REPLACEALL,,,
-kspell,KS_STOP,,,
-kspell,KS_SUGGEST,,,
-kspell,KSpell,,,
-kspell,KSpellConfig,,,
-kspell,KSpellDlg,,,
+tdemdi,KMdi,,,
+tdemdi,KMdiChildArea,,,
+tdemdi,KMdiChildFrm,,,
+tdemdi,KMdiChildFrmCaption,,,
+tdemdi,KMdiChildFrmDragBeginEvent,,,
+tdemdi,KMdiChildFrmDragEndEvent,,,
+tdemdi,KMdiChildFrmMoveEvent,,,
+tdemdi,KMdiChildFrmResizeBeginEvent,,,
+tdemdi,KMdiChildFrmResizeEndEvent,,,
+tdemdi,KMdiChildView,,,
+tdemdi,KMdiMainFrm,,,
+tdemdi,KMdiTaskBar,,,
+tdemdi,KMdiTaskBarButton,,,
+tdemdi,KMdiToolViewAccessor,,,
+tdemdi,KMdiViewCloseEvent,,,
+tdemdi,KMdiWin32IconButton,,,
+tdeparts,KParts,,,
+tdeparts,createReadOnlyPart,,,
+tdeparts,createReadWritePart,,,
+tdeparts,testTQMapTQCStringInt,,,
+tdespell,KS_ADD,,,
+tdespell,KS_CANCEL,,,
+tdespell,KS_CLIENT_ASPELL,,,
+tdespell,KS_CLIENT_HSPELL,,,
+tdespell,KS_CLIENT_ISPELL,,,
+tdespell,KS_CONFIG,,,
+tdespell,KS_E_ASCII,,,
+tdespell,KS_E_CP1251,,,
+tdespell,KS_E_CP1255,,,
+tdespell,KS_E_KOI8R,,,
+tdespell,KS_E_KOI8U,,,
+tdespell,KS_E_LATIN1,,,
+tdespell,KS_E_LATIN13,,,
+tdespell,KS_E_LATIN15,,,
+tdespell,KS_E_LATIN2,,,
+tdespell,KS_E_LATIN3,,,
+tdespell,KS_E_LATIN4,,,
+tdespell,KS_E_LATIN5,,,
+tdespell,KS_E_LATIN7,,,
+tdespell,KS_E_LATIN8,,,
+tdespell,KS_E_LATIN9,,,
+tdespell,KS_E_UTF8,,,
+tdespell,KS_IGNORE,,,
+tdespell,KS_IGNOREALL,,,
+tdespell,KS_REPLACE,,,
+tdespell,KS_REPLACEALL,,,
+tdespell,KS_STOP,,,
+tdespell,KS_SUGGEST,,,
+tdespell,KSpell,,,
+tdespell,KSpellConfig,,,
+tdespell,KSpellDlg,,,
diff --git a/examples/pytde-sampler/sampler.py b/examples/pytde-sampler/sampler.py
index 183b185..f90a1bb 100755
--- a/examples/pytde-sampler/sampler.py
+++ b/examples/pytde-sampler/sampler.py
@@ -22,8 +22,8 @@ from tdeui import KMainWindow, KPushButton, KSplashScreen, KStdAction
from tdeui import KKeyDialog, KEditToolbar
from kio import KTrader
-from kparts import createReadOnlyPart, createReadWritePart
-from khtml import KHTMLPart
+from tdeparts import createReadOnlyPart, createReadWritePart
+from tdehtml import KHTMLPart
import about
import lib
@@ -152,7 +152,7 @@ class WebFrame(CommonFrame):
def __init__(self, parent):
CommonFrame.__init__(self, parent)
self.part = part = buildPart(self, 'text/html', "Type == 'Service'")
- #part.connect(part, SIGNAL('khtmlMousePressEvent(a)'), self.onURL)
+ #part.connect(part, SIGNAL('tdehtmlMousePressEvent(a)'), self.onURL)
def onURL(self, a):
print '****', a
diff --git a/examples/uikmdi.rc b/examples/uitdemdi.rc
index a7e2196..a7e2196 100644
--- a/examples/uikmdi.rc
+++ b/examples/uitdemdi.rc
diff --git a/examples/uikmdi.py b/examples/uitdemdi.py
index 6c9cc21..f746384 100644
--- a/examples/uikmdi.py
+++ b/examples/uitdemdi.py
@@ -2,7 +2,7 @@
"""
This is a rough Python translation of the ideas presented in this KMDI tutorial:
- http://web.tiscali.it/andreabergia/kmditutorial.html
+ http://web.tiscali.it/andreabergia/tdemditutorial.html
What does work:
@@ -33,7 +33,7 @@ from tdecore import i18n, TDEAboutData, TDEApplication, TDEGlobal, KIcon, TDECmd
from tdeui import KDockWidget, KListBox, KStdAction
try:
- from kmdi import KMdi, KMdiMainFrm, KMdiChildView
+ from tdemdi import KMdi, KMdiMainFrm, KMdiChildView
except (ImportError, ):
print 'Exception importing KMDI; check your PyKDE installation'
sys.exit(1)
@@ -55,7 +55,7 @@ class KmdiExample(KMdiMainFrm):
""" KmdiExample(parent=None) -> an example KMdiMainFrm window
"""
- uifilebase = 'uikmdi.rc'
+ uifilebase = 'uitdemdi.rc'
viewIcons = ('network', 'email', 'stop', 'back', 'forward', )
toolIcons = ('view_icon', 'configure')
@@ -167,7 +167,7 @@ class KmdiExample(KMdiMainFrm):
try:
caption = which.tabCaption()
except (AttributeError, ):
## probably None; bug in kmdi?
return
self.removeMainToolItem(which)
which.close()
@@ -167,7 +167,7 @@ class KmdiExample(KMdiMainFrm):
caption = which.tabCaption()
except (AttributeError, ):
- ## probably None; bug in kmdi?
+ ## probably None; bug in tdemdi?
return
self.removeMainToolItem(which)